contexttools.Context
====================

.. abjad-lineage:: abjad.tools.contexttools.Context.Context.Context

.. autoclass:: abjad.tools.contexttools.Context.Context.Context
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.descendants
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.leaves
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.lineage
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.music
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.override
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.parent
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.parentage
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.prolation
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.set
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.spanners
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.start_offset
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.timespan
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.context_name
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.Context.Context.Context.append
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.extend
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.index
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.insert
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.pop
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__add__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__contains__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__delitem__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__getitem__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__iadd__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__imul__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__len__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__mul__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__radd__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__rmul__
   :noindex:

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__setitem__
   :noindex:
